@@ -21,7 +21,7 @@ use base qw( Test::Builder::Module );
 use Carp qw( croak );
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -55,6 +55,7 @@ sub new
     t           => $t, 
     urls        => [], 
     apps        => [], 
+    stopped     => [],
     index       => -1,
     url         => '', 
     servers     => [],
@@ -158,6 +159,8 @@ sub _add_ua
   for(my $i=0; $i<=$max; $i++)
   {
     next unless defined $self->{apps}->[$i];
+    my $stopped = $self->{stopped}->[$i];
+    next if $stopped;
     $self->_add_app_to_ua($ua, $self->{urls}->[$i], $self->{apps}->[$i], $i);
   }
   push @{ $self->{extra_ua} }, $ua;
@@ -438,6 +441,8 @@ sub stop_ok
     $ok = 0;
   }
   
+  $self->{stopped}->[$index] = 1 if $ok;
+  
   $test_name //= "stop service ($index)";
   
   my $ret = $tb->ok($ok, $test_name);
@@ -474,12 +479,40 @@ sub start_ok
     $ok = 0;
   }
   
+  $self->{stopped}->[$index] = 0 if $ok;
+
   $test_name //= "start service ($index)";
   
   $tb->ok($ok, $test_name);
 }
 
 
+sub is_stopped
+{
+  my($self, $index, $test_name) = @_;
+  
+  my $ok = !!$self->{stopped}->[$index];
+  
+  $test_name //= "servers ($index) is stopped";
+  
+  my $tb = __PACKAGE__->builder;
+  $tb->ok($ok, $test_name);
+}
+
+
+sub isnt_stopped
+{
+  my($self, $index, $test_name) = @_;
+  
+  my $ok = !$self->{stopped}->[$index];
+  
+  $test_name //= "servers ($index) is not stopped";
+  
+  my $tb = __PACKAGE__->builder;
+  $tb->ok($ok, $test_name);
+}
+
+
 sub create_ua
 {
   shift->_add_ua;
@@ -499,7 +532,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -763,9 +796,9 @@ For example:
  use Test::More;
  BEGIN {
    plan skip_all => 'test requires Clustericious 0.9925'
-     unless eval q{ use Clustericious 0.9925; 1 };
+     unless eval q{ use Clustericious 1.00; 1 };
    plan skip_all => 'test requires PlugAuth::Lite'
-     unless eval q{ use PlugAuth::Lite; 1 };
+     unless eval q{ use PlugAuth::Lite 0.30; 1 };
  };
 
 =head2 stop_ok
@@ -789,6 +822,20 @@ Start the given service.  The service is specified by
 an index, the first application when you created the
 cluster is 0, the second is 1, and so on.
 
+=head2 is_stopped
+
+ $cluster->is_stopped( $index );
+ $cluster->is_stopped( $index, $test_name );
+
+Passes if the given service is stopped.
+
+=head2 isnt_stopped
+
+ $cluster->isnt_stopped( $index );
+ $cluster->isnt_stopped( $index, $test_name );
+
+Passes if the given service is not stopped.
+
 =head2 create_ua
 
  my $ua = $cluster->create_ua;
@@ -815,8 +862,6 @@ https://github.com/plicease/Test-Clustericious-Cluster/issues/3
 
 If you want to help.
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
